@@ -1092,7 +1092,7 @@ END_HTML
     return $html;
 }
 
-sub balances {
+sub account_balances {
     my $html = << 'END_HTML';
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
 <html lang="ja"><head>
